# ansible-vault-decrypt

Tool for decrypt ansible inline vault passwords.

## usage

```
ansible-vault-decrypt

positional arguments:
  encrypted_file        Path to file to decrypt

options:
  -h, --help            show this help message and exit
  -d                    debug mode output
  --vault-password-file VAULT_PASSWORD_FILE
                        vault password file
```
